@@ -1,5 +1,5 @@
-from src.OOTUI.SuperDrawable import SuperDrawable
-from src.OOTUI.Vector2 import Vector2
+from .SuperDrawable import SuperDrawable
+from .Vector2 import Vector2
 
 
 class Rect(SuperDrawable):
